@@ -4,9 +4,9 @@ use Types::Path::Tiny qw(Dir);
 use Types::Common::String qw(NonEmptySimpleStr NonEmptyStr);
 use Types::PerlVersion qw(PerlVersion);
 use Types::Standard qw(Maybe);
-use Data::Dump::Streamer qw(Dump);
+use Data::Dumper qw(Dumper);
 use Moo::Role;
-our $VERSION = '1.0.1'; # VERSION
+our $VERSION = '1.0.2'; # VERSION
 # ABSTRACT: common role for tools that generate packages
 
 
@@ -47,7 +47,15 @@ requires 'hash_variable_name';
 sub write_out {
     my ($self, $hashref) = @_;
 
-    my $data_str = Dump($hashref)->Indent(1)->Terse(1)->SortKeys('lexical')->Out;
+    my $data_str = Data::Dumper->new([$hashref])
+        ->Indent(1)
+        ->Trailingcomma(1)
+        ->Purity(1)
+        ->Useqq(0)
+        ->Terse(1)
+        ->Quotekeys(1)
+        ->Sortkeys(1)
+        ->Dump;
     $data_str =~ s[^\{][(];
     $data_str =~ s[\};?$][)];
 
@@ -114,7 +122,7 @@ Data::Password::zxcvbn::AuthorTools::PackageWriter - common role for tools that
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 DESCRIPTION
 
